<?php
namespace Neklo\Scheduler\Block\Adminhtml\Schedule;

use Neklo\Scheduler\Controller\Adminhtml\Schedule\Edit as EditCtrl;
use Neklo\Scheduler\Api\Data\SchedulerInterface;

class Edit extends \Magento\Backend\Block\Widget\Form\Container
{
    /**
     * @var \Magento\Framework\Registry
     */
    protected $registry;

    /**
     * @param \Magento\Backend\Block\Widget\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Widget\Context $context,
        \Magento\Framework\Registry $registry,
        array $data = []
    ) {
        $this->registry = $registry;
        parent::__construct($context, $data);
    }

    /**
     * Initialize edit block
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_objectId = SchedulerInterface::SCHEDULE_ID;
        $this->_blockGroup = 'Neklo_Scheduler';
        $this->_controller = 'adminhtml_schedule';

        parent::_construct();

        if ($this->_isAllowedAction('Neklo_Scheduler::edit')) {
            $this->buttonList->update('save', 'label', __('Save Schedule'));
            $this->buttonList->add(
                'saveandcontinue',
                [
                    'label' => __('Save and Continue Edit'),
                    'class' => 'save',
                    'data_attribute' => [
                        'mage-init' => [
                            'button' => ['event' => 'saveAndContinueEdit', 'target' => '#edit_form'],
                        ],
                    ]
                ],
                -100
            );
            $this->buttonList->update('delete', 'label', __('Delete Schedule'));
        } else {
            $this->buttonList->remove('save');
            $this->buttonList->remove('delete');
        }
    }

    /**
     * Retrieve text for header element depending on loaded page
     *
     * @return \Magento\Framework\Phrase
     */
    public function getHeaderText()
    {
        if ($this->registry->registry(EditCtrl::MODEL_REGISTRY)->getId()) {
            return __("Edit Schedule: '%1'", $this->escapeHtml($this->registry
                ->registry(EditCtrl::MODEL_REGISTRY)->getJobCode()));
        } else {
            return __('New Schedule');
        }
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }

    /**
     * Getter of url for "Save and Continue" button
     * tab_id will be replaced by desired by JS later
     *
     * @return string
     */
    protected function _getSaveAndContinueUrl()
    {
        return $this->getUrl('*/*/save', ['_current' => true, 'back' => 'edit']);
    }
}
